@@ -68,7 +68,7 @@ setMethod("fcs_files.download", signature(UserSession="UserSession"), function(U
 
         download_status<-utils::download.file(url=parse(resp)$downloadUrl,
                                               destfile=file.path(directory,file_name),
-                                              method = 'auto', quiet = FALSE)
+                                              method = 'auto', quiet = FALSE, mode = 'wb')
 
         if(download_status!=0){
             print('Cannot download the file.')
